@@ -173,6 +173,7 @@ def write_log(string: str = "", print_file: object = sys.stdout):
 def log(string: str, print_sep: str = ' ', print_end: str = "\n", print_file: object = sys.stdout,
         print_flush: bool = None) -> None:
     global log_style
+    string = string if string is not None else ""
     if log_style == LOG_STYLE_LOG:
         write_log(string, print_file)
     elif log_style == LOG_STYLE_PRINT:
@@ -551,7 +552,7 @@ def local_path_generate(folder_name: str, file_name: str = "",
     return work_path
 
 
-def write_file(path: str, mode: str, string: str, encoding: str = "utf-8") -> None:
+def write_file(path: str, mode: str, string: str, encoding: str = "utf-8") -> bool:
     """
     写文件
     :param path: 文件路径
@@ -565,8 +566,10 @@ def write_file(path: str, mode: str, string: str, encoding: str = "utf-8") -> No
             f.write(string)
         f.close()
         log("写入文件{}成功".format(path))
+        return True
     except Exception as e:
         log(string="写入文件{}失败：{}".format(path, e), print_file=sys.stderr)
+        return False
 
 
 def cookieString2CookieJar(cookie: str = "") -> RequestsCookieJar:
@@ -631,7 +634,7 @@ def save_obj(src: object, path: str = "") -> bool:
     :param path: 保存的路径
     :return: 返回是否保存成功,True 表示成功
     """
-    path = path if len(path) > 0 else local_path_generate("", suffix=".db")
+    path = path if len(path) > 0 else local_path_generate("", suffix="." + type(src))
     try:
         with open(path, mode="wb") as f:
             pickle.dump(src, f, pickle.HIGHEST_PROTOCOL)
